@@ -5,11 +5,14 @@ use Moose;
 with 'Pod::Weaver::Role::Section';
 
 use List::Util qw(first);
+use Perinci::Access::Perl;
 use Perinci::To::POD;
 use Pod::Elemental;
 use Pod::Elemental::Element::Nested;
 
-our $VERSION = '0.12'; # VERSION
+our $VERSION = '0.13'; # VERSION
+
+our $pa = Perinci::Access::Perl->new;
 
 # regex
 has exclude_modules => (
@@ -61,16 +64,31 @@ sub weave_section {
 
     # generate the POD and insert it to FUNCTIONS section
     my $url = $package; $url =~ s!::!/!g; $url = "pl:/$url/";
-    my $doc = Perinci::To::POD->new(url => $url);
+    my $res;
+    $res = $pa->request(meta => $url);
+    die "Can't meta $url: $res->[0] - $res->[1]" unless $res->[0] == 200;
+    my $meta = $res->[2];
+    $res = $pa->request(child_metas => $url);
+    die "Can't child_metas $url: $res->[0] - $res->[1]" unless $res->[0] == 200;
+    my $cmetas = $res->[2];
+    my $doc = Perinci::To::POD->new(
+        name=>$package, meta=>$meta, child_metas=>$cmetas);
     $doc->delete_doc_section('summary'); # already handled by other plugins
     $doc->delete_doc_section('version'); # ditto
     my $pod_text = $doc->gen_doc;
 
     my $found;
     while ($pod_text =~ /^=head1 ([^\n]+)\n(.+?)(?=^=head1|\z)/msg) {
+        my ($sectname, $sectcontent) = ($1, $2);
+
+        # skip inserting section if there is no text
+        next unless $sectcontent =~ /\S/;
+
+        # skip inserting FUNCTIONS if there are no functions
+        next if $sectname =~ /functions/i && $sectcontent !~ /^=head2/m;
+
         $found++;
         #$self->log(["generated POD section %s", $1]);
-        my ($sectname, $sectcontent) = ($1, $2);
         my $elem = Pod::Elemental::Element::Nested->new({
             command  => 'head1',
             content  => $sectname,
@@ -105,13 +123,15 @@ __END__
 
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 Pod::Weaver::Plugin::Perinci - Insert POD from Rinci metadata
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -135,6 +155,23 @@ L<Perinci::To::POD>
 
 L<Pod::Weaver>
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Pod-Weaver-Plugin-Perinci>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-Pod-Weaver-Plugin-Perinci>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+http://rt.cpan.org/Public/Dist/Display.html?Name=Pod-Weaver-Plugin-Perinci
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
